/*
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <string.h>
#include <gtk/gtk.h>

#include "xfbib-bibtex-preamble.h"
#include "xfbib-bibtex-value.h"

struct _XfbibBibtexPreamble
{
	GObject parent;
	GObject *owner;
	gchar separator;
	XfbibBibtexValue *value;
};

typedef struct _XfbibBibtexPreambleClass
{
	GObjectClass parent;
} XfbibBibtexPreambleClass;

static void xfbib_bibtex_preamble_class_init(XfbibBibtexPreambleClass *klass);

static void xfbib_bibtex_preamble_init(XfbibBibtexPreamble *instance);
static void xfbib_bibtex_preamble_finalize(GObject *obj);

G_DEFINE_TYPE(XfbibBibtexPreamble, xfbib_bibtex_preamble, G_TYPE_OBJECT)

static void
xfbib_bibtex_preamble_class_init(XfbibBibtexPreambleClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	object_class->finalize = xfbib_bibtex_preamble_finalize;
}

static void
xfbib_bibtex_preamble_init(XfbibBibtexPreamble *instance)
{
	instance->value = xfbib_bibtex_value_new(G_OBJECT(instance));
}

static void
xfbib_bibtex_preamble_finalize(GObject *obj)
{
	G_OBJECT_CLASS(xfbib_bibtex_preamble_parent_class)->finalize(obj);
}

XfbibBibtexPreamble *
xfbib_bibtex_preamble_new(GObject *obj)
{
	XfbibBibtexPreamble *preamble;
	preamble = g_object_new(XFBIB_TYPE_BIBTEX_PREAMBLE, NULL);
	preamble->owner = obj;
	return preamble;
}


GObject *
xfbib_bibtex_preamble_get_owner(XfbibBibtexPreamble *preamble)
{
	g_return_val_if_fail(XFBIB_IS_BIBTEX_PREAMBLE(preamble), NULL);
	return preamble->owner;
}
	
gboolean
xfbib_bibtex_preamble_parse(XfbibBibtexPreamble *preamble, const gchar *s)
{
	gchar *str, *tmp;
	g_return_val_if_fail(XFBIB_IS_BIBTEX_PREAMBLE(preamble), FALSE);

	str = g_strdup(s + 9);
	g_strstrip(str);
	preamble->separator = str[0];

	tmp = g_strndup(str + 1, strlen(str) - 2);

	if (!xfbib_bibtex_value_parse(preamble->value, tmp)) {
		g_free(tmp);
		g_free(str);
		return FALSE;
	}
	g_free(tmp);
	g_free(str);
	return TRUE;
}

gchar
xfbib_bibtex_preamble_get_separator(XfbibBibtexPreamble *preamble)
{
	g_return_val_if_fail(XFBIB_IS_BIBTEX_PREAMBLE(preamble), '\0');
	return preamble->separator;
}

XfbibBibtexValue *
xfbib_bibtex_preamble_get_value(XfbibBibtexPreamble *preamble)
{
	g_return_val_if_fail(XFBIB_IS_BIBTEX_PREAMBLE(preamble), NULL);
	return preamble->value;
}

