/* 
 * Copyright (c) 2008 Jesper Karlsson & David Gustafsson
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>

#include "xfbib-single-input.h"

struct _XfbibSingleInput
{
	GtkHBox parent;
	GtkWidget *label;
	GtkWidget *entry;
	//GtkWidget *toggle_button;
};

typedef struct _XfbibSingleInputClass
{
	GtkHBoxClass parent;
} XfbibSingleInputClass;

static void xfbib_single_input_class_init(XfbibSingleInputClass *klass);

static void xfbib_single_input_init(XfbibSingleInput *instance);
static void xfbib_single_input_finalize(GObject *obj);

static GObjectClass *xfbib_single_input_parent_class = NULL;

GType
xfbib_single_input_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
		static const GTypeInfo info = {
			sizeof (XfbibSingleInputClass),
			NULL,   /* base_init */
			NULL,   /* base_finalize */
			(GClassInitFunc) xfbib_single_input_class_init,   /* class_init */
			NULL,   /* class_finalize */
			NULL,   /* class_data */
			sizeof (XfbibSingleInput),
			0,      /* n_preallocs */
			(GInstanceInitFunc) xfbib_single_input_init    /* instance_init */
		};
		type = g_type_register_static (GTK_TYPE_HBOX, "XfbibSingleInput", &info, 0);
	}
	return type;
}

	
static void
xfbib_single_input_class_init(XfbibSingleInputClass *klass)
{
	GObjectClass *object_class = (GObjectClass *)klass;
	
	xfbib_single_input_parent_class = g_type_class_peek_parent (klass); 

	object_class->finalize = xfbib_single_input_finalize;
}

static void
xfbib_single_input_init(XfbibSingleInput *instance)
{
	gtk_box_set_spacing(GTK_BOX(instance), 12);

	instance->label = gtk_label_new("");
	
	instance->entry = gtk_entry_new();
	gtk_entry_set_width_chars(GTK_ENTRY(instance->entry), -1);
	
	//instance->toggle_button = gtk_toggle_button_new_with_label("aA");
	//gtk_widget_set_tooltip_text (instance->toggle_button, "Toggle case sensitivity.");
	
	/* Pack the buttons */
	gtk_box_pack_start(GTK_BOX(instance), instance->label, FALSE, FALSE, 3);
	//gtk_box_pack_end(GTK_BOX(instance), instance->toggle_button, FALSE, TRUE, 10);
	gtk_box_pack_end(GTK_BOX(instance), instance->entry, TRUE, TRUE, 3);
	gtk_widget_show_all(GTK_WIDGET(instance));
}

static void
xfbib_single_input_finalize(GObject *obj)
{
	G_OBJECT_CLASS(xfbib_single_input_parent_class)->finalize(obj);
}

GtkWidget *
xfbib_single_input_new(gchar *label, gchar *tooltip)
{
	XfbibSingleInput *single_input;
	single_input = g_object_new(XFBIB_TYPE_SINGLE_INPUT, NULL);
	gtk_label_set_text(GTK_LABEL(single_input->label), label);
	gtk_widget_set_tooltip_text(single_input->entry, tooltip);
	return GTK_WIDGET(single_input);
}

void
xfbib_single_input_set_entry_text(XfbibSingleInput *single_input, const gchar *text)
{
	gtk_entry_set_text(GTK_ENTRY (single_input->entry), text);
}

const gchar *
xfbib_single_input_get_entry_text(XfbibSingleInput *single_input)
{
	return gtk_entry_get_text(GTK_ENTRY (single_input->entry));
}

